systemtools.ImportManager
=========================

.. abjad-lineage:: abjad.tools.systemtools.ImportManager.ImportManager

.. autoclass:: abjad.tools.systemtools.ImportManager.ImportManager

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.ImportManager.ImportManager.import_material_packages
      ~abjad.tools.systemtools.ImportManager.ImportManager.import_nominative_modules
      ~abjad.tools.systemtools.ImportManager.ImportManager.import_public_names_from_path_into_namespace
      ~abjad.tools.systemtools.ImportManager.ImportManager.import_structured_package

Bases
-----

- :py:class:`__builtin__.object <object>`

Static methods
--------------

.. automethod:: abjad.tools.systemtools.ImportManager.ImportManager.import_material_packages
   :noindex:

.. automethod:: abjad.tools.systemtools.ImportManager.ImportManager.import_nominative_modules
   :noindex:

.. automethod:: abjad.tools.systemtools.ImportManager.ImportManager.import_public_names_from_path_into_namespace
   :noindex:

.. automethod:: abjad.tools.systemtools.ImportManager.ImportManager.import_structured_package
   :noindex:
